require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Finman
    module Account

      # DTO for set command of account.<br>
      class AccountSetAttributes < UU::OS::REST::DTO

        # Name of account. Its value is automatically trimmed.
        # Cannot be null nor empty string nor longer than 250 characters and can contain only characters allowed for BTName.
        # The create command fails otherwise.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of account. Its value is automatically trimmed.
        # The code must be unique in target territory. It cannot be empty string nor longer than 250 characters
        # and can contain only characters allowed for BTCode. The create command will fail otherwise.
        # When null is set, the code is generated automatically.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of account.
        # When null is set, the description is taken from the meta artifact. When the meta artifact does not define it, it remains empty.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of the role competent for account.
        # When null is set, competent role will be taken from authorization.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # Bank account number of account.
        # When null is set, the create command will fail.
        # @param [String]
        # @return [String]
        attr_accessor :bank_account_number

        # Iban number of account.
        # @param [String]
        # @return [String]
        attr_accessor :iban

        # Authorized overdraft of account.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :authorized_overdraft

        # Minimal balance in account.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :minimal_balance

        # Note of account.
        # @param [String]
        # @return [String]
        attr_accessor :note

        # Registered account of account.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        # This parameter cannot be used for Cash Account.
        attr_accessor :registered_account

        # Bank order owner uri of account
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :bank_orders_owner_uri

        # Bank orders folder of account
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :bank_orders_folder_uri

        # Days expected paydate bank order of account
        # @param [Fixnum]
        # @return [Fixnum]
        # This parameter cannot be used for Cash Account.
        attr_accessor :days_expected_paydate_bo

        # Maximal payments bank orders Artifact of account
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_payments_bank_orders_artifact

        # Number of referenced bank orders.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :number_of_referenced_bo

        # Teller uri
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :teller_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def bank_account_number
          attributes[:bankAccountNumber]
        end

        def bank_account_number=(val)
          attributes[:bankAccountNumber] = val
        end


        def iban
          attributes[:iban]
        end

        def iban=(val)
          attributes[:iban] = val
        end


        def authorized_overdraft
          attributes[:authorizedOverdraft]
        end

        def authorized_overdraft=(val)
          attributes[:authorizedOverdraft] = val
        end


        def minimal_balance
          attributes[:minimalBalance]
        end

        def minimal_balance=(val)
          attributes[:minimalBalance] = val
        end


        def note
          attributes[:note]
        end

        def note=(val)
          attributes[:note] = val
        end


        def registered_account
          attributes[:registeredAccount]
        end

        def registered_account=(val)
          attributes[:registeredAccount] = val
        end


        def bank_orders_owner_uri
          attributes[:bankOrdersOwnerUri]
        end

        def bank_orders_owner_uri=(val)
          if val
            attributes[:bankOrdersOwnerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:bankOrdersOwnerUri] = nil
          end
        end


        def bank_orders_folder_uri
          attributes[:bankOrdersFolderUri]
        end

        def bank_orders_folder_uri=(val)
          if val
            attributes[:bankOrdersFolderUri] = UU::OS::UESURI.new(val)
          else
            attributes[:bankOrdersFolderUri] = nil
          end
        end


        def days_expected_paydate_bo
          attributes[:daysExpectedPaydateBO]
        end

        def days_expected_paydate_bo=(val)
          attributes[:daysExpectedPaydateBO] = val
        end


        def max_payments_bank_orders_artifact
          attributes[:maxPaymentsBankOrdersArtifact]
        end

        def max_payments_bank_orders_artifact=(val)
          attributes[:maxPaymentsBankOrdersArtifact] = val
        end

        def number_of_referenced_bo
          attributes[:numberOfReferencedBO]
        end

        def number_of_referenced_bo=(val)
          attributes[:numberOfReferencedBO] = val
        end

        def teller_uri
          attributes[:tellerUri]
        end

        def teller_uri=(val)
          if val
            attributes[:tellerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:tellerUri] = nil
          end
        end

      end
    end
  end
end

