require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU

  module Finman

    module BusinessCase

      # Value object containing attributes available to modify on a Business Case entity.
      class BusinessCaseSetAttributes < UU::OS::REST::DTO

        # Name of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of created Business Case.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # Code of business case currency. Must be one from territory allowed reporting currencies.
        # Can be changed only if business case has no transactions or only cancelled transactions.
        # @param [String]
        # @return [String]
        attr_accessor :currency

        # URI of company of created Business Case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :business_case_company_uri

        # URI of related business case of interterritorial business case.
        # If you try to set access role for payments on non interterriorial business case, command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :related_business_case_uri

        # URI of counterparty business case of interterritorial business case.
        # If you try to set access role for payments on non interterriorial business case, command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :counterparty_business_case_uri

        # URI of access role for payments of interterritorial business case.
        # If you try to set access role for payments on non interterriorial business case, command will fail.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :access_role_for_payments_uri

        # URI of default account of the business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :default_account_uri

        # Default account number of the business case.
        # @param [String]
        # @return [String]
        attr_accessor :default_account_number

        # URI of incoming invoice clerk's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_invoice_clerk_uri

        # URI of outgoing invoice clerk's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_invoice_clerk_uri

        # URI of accountant's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :accountant_uri

        # URI of teller's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :teller_uri

        # URI of role of the teller's manager.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :tellers_manager_uri

        # URI of incoming payment checker's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_payment_checker_uri

        # URI of role of the incoming payment checker's manager.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :incoming_payment_checkers_manager_uri

        # URI of outgoing payment checker's role.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_payment_checker_uri

        # URI of role of the outgoing payment checker's manager.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :outgoing_payment_checkers_manager_uri

        # URI of default financial category of credit side of payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :payment_default_debit_financial_category_uri

        # URI of default financial category of credit side of fast payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :fast_payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of fast payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :fast_payment_default_debit_financial_category_uri
        
        # URI of default financial category of credit side of financial transfer.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_default_credit_financial_category_uri

        # URI of default financial category of debit side of financial transfer.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :transfer_default_debit_financial_category_uri

        # URI of default financial category of credit side of ex-post payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_payment_default_credit_financial_category_uri

        # URI of default financial category of debit side of ex-post payment.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :expost_payment_default_debit_financial_category_uri

        # URI of default financial category of supplier's side of credit note.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_supplier_default_financial_category_uri

        # URI of default financial category of client's side of credit note.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_note_client_default_financial_category_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def business_case_company_uri
          attributes[:businessCaseCompanyUri]
        end

        def business_case_company_uri=(val)
          if val
            attributes[:businessCaseCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:businessCaseCompanyUri] = nil
          end
        end

        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end

        def related_business_case_uri
          attributes[:relatedBusinessCaseUri]
        end

        def related_business_case_uri=(val)
          if val
            attributes[:relatedBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:relatedBusinessCaseUri] = nil
          end
        end

        def counterparty_business_case_uri
          attributes[:counterpartyBusinessCaseUri]
        end

        def counterparty_business_case_uri=(val)
          if val
            attributes[:counterpartyBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:counterpartyBusinessCaseUri] = nil
          end
        end

        def counterparty_business_case_uri=(val)
          attributes[:counterpartyBusinessCaseUri] = val
        end

        def access_role_for_payments_uri=(val)
          attributes[:accessRoleForPaymentsUri] = val
        end

        def access_role_for_payments_uri
          attributes[:accessRoleForPaymentsUri]
        end

        def default_account_uri
          attributes[:defaultAccountUri]
        end

        def default_account_uri=(val)
          if val
            attributes[:defaultAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:defaultAccountUri] = nil
          end
        end

        def default_account_number
          attributes[:defaultAccountNumber]
        end

        def default_account_number=(val)
          attributes[:defaultAccountNumber] = val
        end

        def incoming_invoice_clerk_uri
          attributes[:incomingInvoiceClerkUri]
        end

        def incoming_invoice_clerk_uri=(val)
          if val
            attributes[:incomingInvoiceClerkUri] = UU::OS::UESURI.new(val)
          else
            attributes[:incomingInvoiceClerkUri] = nil
          end
        end

        def outgoing_invoice_clerk_uri
          attributes[:outgoingInvoiceClerkUri]
        end

        def outgoing_invoice_clerk_uri=(val)
          if val
            attributes[:outgoingInvoiceClerkUri] = UU::OS::UESURI.new(val)
          else
            attributes[:outgoingInvoiceClerkUri] = nil
          end
        end

        def accountant_uri
          attributes[:accountantUri]
        end

        def accountant_uri=(val)
          attributes[:accountantUri] = val
        end

        def teller_uri
          attributes[:tellerUri]
        end

        def teller_uri=(val)
          if val
            attributes[:tellerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:tellerUri] = nil
          end
        end

        def tellers_manager_uri
          attributes[:tellersManagerUri]
        end

        def tellers_manager_uri=(val)
          if val
            attributes[:tellersManagerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:tellersManagerUri] = nil
          end
        end

        def incoming_payment_checker_uri
          attributes[:incomingPaymentCheckerUri]
        end

        def incoming_payment_checker_uri=(val)
          if val
            attributes[:incomingPaymentCheckerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:incomingPaymentCheckerUri] = nil
          end
        end

        def incoming_payment_checkers_manager_uri
          attributes[:incomingPaymentCheckersManagerUri]
        end

        def incoming_payment_checkers_manager_uri=(val)
          if val
            attributes[:incomingPaymentCheckersManagerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:incomingPaymentCheckersManagerUri] = nil
          end
        end

        def outgoing_payment_checker_uri
          attributes[:outgoingPaymentCheckerUri]
        end

        def outgoing_payment_checker_uri=(val)
          if val
            attributes[:outgoingPaymentCheckerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:outgoingPaymentCheckerUri] = nil
          end
        end

        def outgoing_payment_checkers_manager_uri
          attributes[:outgoingPaymentCheckersManagerUri]
        end

        def outgoing_payment_checkers_manager_uri=(val)
          if val
            attributes[:outgoingPaymentCheckersManagerUri] = UU::OS::UESURI.new(val)
          else
            attributes[:outgoingPaymentCheckersManagerUri] = nil
          end
        end

        def payment_default_credit_financial_category_uri
          attributes[:paymentDefaultCreditFinancialCategoryUri]
        end

        def payment_default_credit_financial_category_uri=(val)
          if val
            attributes[:paymentDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:paymentDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def payment_default_debit_financial_category_uri
          attributes[:paymentDefaultDebitFinancialCategoryUri]
        end

        def payment_default_debit_financial_category_uri=(val)
          if val
            attributes[:paymentDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:paymentDefaultDebitFinancialCategoryUri] = nil
          end
        end

        def fast_payment_default_credit_financial_category_uri
          attributes[:fastPaymentDefaultCreditFinancialCategoryUri]
        end

        def fast_payment_default_credit_financial_category_uri=(val)
          if val
            attributes[:fastPaymentDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:fastPaymentDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def fast_payment_default_debit_financial_category_uri
          attributes[:fastPaymentDefaultDebitFinancialCategoryUri]
        end

        def fast_payment_default_debit_financial_category_uri=(val)
          if val
            attributes[:fastPaymentDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:fastPaymentDefaultDebitFinancialCategoryUri] = nil
          end
        end
        
        def transfer_default_credit_financial_category_uri
          attributes[:transferDefaultCreditFinancialCategoryUri]
        end

        def transfer_default_credit_financial_category_uri=(val)
          if val
            attributes[:transferDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:transferDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def transfer_default_debit_financial_category_uri
          attributes[:transferDefaultDebitFinancialCategoryUri]
        end

        def transfer_default_debit_financial_category_uri=(val)
          if val
            attributes[:transferDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:transferDefaultDebitFinancialCategoryUri] = nil
          end
        end

        def expost_payment_default_credit_financial_category_uri
          attributes[:expostPaymentDefaultCreditFinancialCategoryUri]
        end

        def expost_payment_default_credit_financial_category_uri=(val)
          if val
            attributes[:expostPaymentDefaultCreditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:expostPaymentDefaultCreditFinancialCategoryUri] = nil
          end
        end

        def expost_payment_default_debit_financial_category_uri
          attributes[:expostPaymentDefaultDebitFinancialCategoryUri]
        end

        def expost_payment_default_debit_financial_category_uri=(val)
          if val
            attributes[:expostPaymentDefaultDebitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:expostPaymentDefaultDebitFinancialCategoryUri] = nil
          end
        end

        def credit_note_supplier_default_financial_category_uri
          attributes[:creditNoteSupplierDefaultFinancialCategoryUri]
        end

        def credit_note_supplier_default_financial_category_uri=(val)
          if val
            attributes[:creditNoteSupplierDefaultFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditNoteSupplierDefaultFinancialCategoryUri] = nil
          end
        end

        def credit_note_client_default_financial_category_uri
          attributes[:creditNoteClientDefaultFinancialCategoryUri]
        end

        def credit_note_client_default_financial_category_uri=(val)
          if val
            attributes[:creditNoteClientDefaultFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditNoteClientDefaultFinancialCategoryUri] = nil
          end
        end
      end
    end
  end
end
