require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Finman
    module FinancialTransaction

      class FinancialTransactionToBePaidAttributes < UU::OS::REST::DTO

        # DTO for get attributes command of financial transaction.
        # @author Vladimír Neckář [vig2i7]
        # URI of the financial transaction.<br>
        # @since FINMAN3-14-06
        attr_accessor :uri

        # URI of meta artifact of the financial transaction.<br>
        # @since FINMAN3-14-06
        attr_accessor :meta_artifact_uri

        # Name of the financial transaction.<br>
        # @since FINMAN3-14-06
        attr_accessor :name

        # Code of the financial transaction.<br>
        # @since FINMAN3-14-06
        attr_accessor :code

        # Amount of the Financial Transaction without vat.
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        attr_accessor :amount_with_vat

        # Constant symbol.
        # Not set for transfers.
        attr_accessor :constant_symbol

        # Number of credit account.
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        attr_accessor :credit_account_uri

        # UESURI of the credit business case
        attr_accessor :credit_business_case_uri

        # Currency of the transaction
        attr_accessor :currency

        # Description for credit side.
        attr_accessor :credit_description

        # UESURI of the Company
        attr_accessor :credit_company_uri

        # Credit vat date of the transaction.
        attr_accessor :credit_vat_date

        # Number of debit account.
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        attr_accessor :debit_account_uri

        # UESURI of the debit business case.
        attr_accessor :debit_business_case_uri

        # Description for debit side.
        attr_accessor :debit_description

        # UESURI of the Company
        attr_accessor :debit_company_uri

        # Debit vat date of the transaction.
        # Not set for transfers.
        attr_accessor :debit_vat_date

        # Date the payment is expected to be payed to.
        # Not set for expost payments.
        attr_accessor :expected_pay_date

        # Specific symbol.
        # Not set for transfers.
        attr_accessor :specific_symbol

        # UESURI pay transaction activity
        attr_accessor :pay_transaction_activity_uri

        # Date of invoicing to the counterparty.
        # Not set for expost payments and transfers.
        attr_accessor :protocol_date

        # Variable symbol.
        # Not set for transfers.
        attr_accessor :variable_symbol

        # Vat rate.
        attr_accessor :vat_rate

        # is transaction interterritorial?
        attr_accessor :interterritorial

        #
        # Application type of the transaction. FAIRPAY for transaction between two Client Accounts, FINMAN for transaction between two Accounts. OTHER for combination of both account types.
        attr_accessor :transaction_app_type

        # Type of account. BANK for Finman Bank Account, CLIENT for FairPay Client Account
        attr_accessor :credit_account_type

        # Type of account. BANK for Finman Bank Account, CLIENT for FairPay Client Account
        attr_accessor :debit_account_type

        # Class of financial transaction (specifies if it is Payment, Payment Copy, Transfer, Expost payment or Credit note).
        attr_accessor :financial_transaction_class

        # Due date.
        attr_accessor :due_date


        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end


        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end


        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end


        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end


        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end


        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end


        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end


        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end


        def credit_business_case_uri
          attributes[:creditBusinessCaseUri]
        end

        def credit_business_case_uri=(val)
          if val
            attributes[:creditBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseUri] = nil
          end
        end


        def currency
          attributes[:currency]
        end

        def currency=(val)
          attributes[:currency] = val
        end


        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end


        def credit_company_uri
          attributes[:creditCompanyUri]
        end

        def credit_company_uri=(val)
          if val
            attributes[:creditCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditCompanyUri] = nil
          end
        end


        def credit_vat_date
          attributes[:creditVatDate]
        end

        def credit_vat_date=(val)
          attributes[:creditVatDate] = val
        end


        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end


        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end


        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end


        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end


        def debit_company_uri
          attributes[:debitCompanyUri]
        end

        def debit_company_uri=(val)
          if val
            attributes[:debitCompanyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitCompanyUri] = nil
          end
        end


        def debit_vat_date
          attributes[:debitVatDate]
        end

        def debit_vat_date=(val)
          attributes[:debitVatDate] = val
        end


        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end


        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def pay_transaction_activity_uri
          attributes[:payTransactionActivityUri]
        end

        def pay_transaction_activity_uri=(val)
          if val
            attributes[:payTransactionActivityUri] = UU::OS::UESURI.new(val)
          else
            attributes[:payTransactionActivityUri] = nil
          end
        end

        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end


        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end


        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end


        def interterritorial
          attributes[:interterritorial]
        end

        def interterritorial=(val)
          attributes[:interterritorial] = val
        end


        def transaction_app_type
          attributes[:transactionAppType]
        end

        def transaction_app_type=(val)
          attributes[:transactionAppType] = val
        end


        def credit_account_type
          attributes[:creditAccountType]
        end

        def credit_account_type=(val)
          attributes[:creditAccountType] = val
        end


        def debit_account_type
          attributes[:debitAccountType]
        end

        def debit_account_type=(val)
          attributes[:debitAccountType] = val
        end


        def financial_transaction_class
          attributes[:financialTransactionClass]
        end

        def financial_transaction_class=(val)
          attributes[:financialTransactionClass] = val
        end


        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end


      end
    end
  end
end

